import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface HealthcareServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#access_policy_object_ids HealthcareService#access_policy_object_ids}.
     *
     * @stability stable
     */
    readonly accessPolicyObjectIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#cosmosdb_key_vault_key_versionless_id HealthcareService#cosmosdb_key_vault_key_versionless_id}.
     *
     * @stability stable
     */
    readonly cosmosdbKeyVaultKeyVersionlessId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#cosmosdb_throughput HealthcareService#cosmosdb_throughput}.
     *
     * @stability stable
     */
    readonly cosmosdbThroughput?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#kind HealthcareService#kind}.
     *
     * @stability stable
     */
    readonly kind?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#location HealthcareService#location}.
     *
     * @stability stable
     */
    readonly location: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#name HealthcareService#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#public_network_access_enabled HealthcareService#public_network_access_enabled}.
     *
     * @stability stable
     */
    readonly publicNetworkAccessEnabled?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#resource_group_name HealthcareService#resource_group_name}.
     *
     * @stability stable
     */
    readonly resourceGroupName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#tags HealthcareService#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * authentication_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#authentication_configuration HealthcareService#authentication_configuration}
     *
     * @stability stable
     */
    readonly authenticationConfiguration?: HealthcareServiceAuthenticationConfiguration;
    /**
     * cors_configuration block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#cors_configuration HealthcareService#cors_configuration}
     *
     * @stability stable
     */
    readonly corsConfiguration?: HealthcareServiceCorsConfiguration;
    /**
     * timeouts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#timeouts HealthcareService#timeouts}
     *
     * @stability stable
     */
    readonly timeouts?: HealthcareServiceTimeouts;
}
/**
 * @stability stable
 */
export interface HealthcareServiceAuthenticationConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#audience HealthcareService#audience}.
     *
     * @stability stable
     */
    readonly audience?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#authority HealthcareService#authority}.
     *
     * @stability stable
     */
    readonly authority?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#smart_proxy_enabled HealthcareService#smart_proxy_enabled}.
     *
     * @stability stable
     */
    readonly smartProxyEnabled?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class HealthcareServiceAuthenticationConfigurationOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _audience?;
    /**
     * @stability stable
     */
    get audience(): string | undefined;
    /**
     * @stability stable
     */
    set audience(value: string | undefined);
    /**
     * @stability stable
     */
    resetAudience(): void;
    /**
     * @stability stable
     */
    get audienceInput(): string | undefined;
    private _authority?;
    /**
     * @stability stable
     */
    get authority(): string | undefined;
    /**
     * @stability stable
     */
    set authority(value: string | undefined);
    /**
     * @stability stable
     */
    resetAuthority(): void;
    /**
     * @stability stable
     */
    get authorityInput(): string | undefined;
    private _smartProxyEnabled?;
    /**
     * @stability stable
     */
    get smartProxyEnabled(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set smartProxyEnabled(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetSmartProxyEnabled(): void;
    /**
     * @stability stable
     */
    get smartProxyEnabledInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface HealthcareServiceCorsConfiguration {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#allow_credentials HealthcareService#allow_credentials}.
     *
     * @stability stable
     */
    readonly allowCredentials?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#allowed_headers HealthcareService#allowed_headers}.
     *
     * @stability stable
     */
    readonly allowedHeaders?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#allowed_methods HealthcareService#allowed_methods}.
     *
     * @stability stable
     */
    readonly allowedMethods?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#allowed_origins HealthcareService#allowed_origins}.
     *
     * @stability stable
     */
    readonly allowedOrigins?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#max_age_in_seconds HealthcareService#max_age_in_seconds}.
     *
     * @stability stable
     */
    readonly maxAgeInSeconds?: number;
}
/**
 * @stability stable
 */
export declare class HealthcareServiceCorsConfigurationOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _allowCredentials?;
    /**
     * @stability stable
     */
    get allowCredentials(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set allowCredentials(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetAllowCredentials(): void;
    /**
     * @stability stable
     */
    get allowCredentialsInput(): boolean | cdktf.IResolvable | undefined;
    private _allowedHeaders?;
    /**
     * @stability stable
     */
    get allowedHeaders(): string[] | undefined;
    /**
     * @stability stable
     */
    set allowedHeaders(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetAllowedHeaders(): void;
    /**
     * @stability stable
     */
    get allowedHeadersInput(): string[] | undefined;
    private _allowedMethods?;
    /**
     * @stability stable
     */
    get allowedMethods(): string[] | undefined;
    /**
     * @stability stable
     */
    set allowedMethods(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetAllowedMethods(): void;
    /**
     * @stability stable
     */
    get allowedMethodsInput(): string[] | undefined;
    private _allowedOrigins?;
    /**
     * @stability stable
     */
    get allowedOrigins(): string[] | undefined;
    /**
     * @stability stable
     */
    set allowedOrigins(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetAllowedOrigins(): void;
    /**
     * @stability stable
     */
    get allowedOriginsInput(): string[] | undefined;
    private _maxAgeInSeconds?;
    /**
     * @stability stable
     */
    get maxAgeInSeconds(): number | undefined;
    /**
     * @stability stable
     */
    set maxAgeInSeconds(value: number | undefined);
    /**
     * @stability stable
     */
    resetMaxAgeInSeconds(): void;
    /**
     * @stability stable
     */
    get maxAgeInSecondsInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface HealthcareServiceTimeouts {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#create HealthcareService#create}.
     *
     * @stability stable
     */
    readonly create?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#delete HealthcareService#delete}.
     *
     * @stability stable
     */
    readonly delete?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#read HealthcareService#read}.
     *
     * @stability stable
     */
    readonly read?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html#update HealthcareService#update}.
     *
     * @stability stable
     */
    readonly update?: string;
}
/**
 * @stability stable
 */
export declare class HealthcareServiceTimeoutsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _create?;
    /**
     * @stability stable
     */
    get create(): string | undefined;
    /**
     * @stability stable
     */
    set create(value: string | undefined);
    /**
     * @stability stable
     */
    resetCreate(): void;
    /**
     * @stability stable
     */
    get createInput(): string | undefined;
    private _delete?;
    /**
     * @stability stable
     */
    get delete(): string | undefined;
    /**
     * @stability stable
     */
    set delete(value: string | undefined);
    /**
     * @stability stable
     */
    resetDelete(): void;
    /**
     * @stability stable
     */
    get deleteInput(): string | undefined;
    private _read?;
    /**
     * @stability stable
     */
    get read(): string | undefined;
    /**
     * @stability stable
     */
    set read(value: string | undefined);
    /**
     * @stability stable
     */
    resetRead(): void;
    /**
     * @stability stable
     */
    get readInput(): string | undefined;
    private _update?;
    /**
     * @stability stable
     */
    get update(): string | undefined;
    /**
     * @stability stable
     */
    set update(value: string | undefined);
    /**
     * @stability stable
     */
    resetUpdate(): void;
    /**
     * @stability stable
     */
    get updateInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html azurerm_healthcare_service}.
 *
 * @stability stable
 */
export declare class HealthcareService extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/healthcare_service.html azurerm_healthcare_service} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: HealthcareServiceConfig);
    private _accessPolicyObjectIds?;
    /**
     * @stability stable
     */
    get accessPolicyObjectIds(): string[] | undefined;
    /**
     * @stability stable
     */
    set accessPolicyObjectIds(value: string[] | undefined);
    /**
     * @stability stable
     */
    resetAccessPolicyObjectIds(): void;
    /**
     * @stability stable
     */
    get accessPolicyObjectIdsInput(): string[] | undefined;
    private _cosmosdbKeyVaultKeyVersionlessId?;
    /**
     * @stability stable
     */
    get cosmosdbKeyVaultKeyVersionlessId(): string | undefined;
    /**
     * @stability stable
     */
    set cosmosdbKeyVaultKeyVersionlessId(value: string | undefined);
    /**
     * @stability stable
     */
    resetCosmosdbKeyVaultKeyVersionlessId(): void;
    /**
     * @stability stable
     */
    get cosmosdbKeyVaultKeyVersionlessIdInput(): string | undefined;
    private _cosmosdbThroughput?;
    /**
     * @stability stable
     */
    get cosmosdbThroughput(): number | undefined;
    /**
     * @stability stable
     */
    set cosmosdbThroughput(value: number | undefined);
    /**
     * @stability stable
     */
    resetCosmosdbThroughput(): void;
    /**
     * @stability stable
     */
    get cosmosdbThroughputInput(): number | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _kind?;
    /**
     * @stability stable
     */
    get kind(): string | undefined;
    /**
     * @stability stable
     */
    set kind(value: string | undefined);
    /**
     * @stability stable
     */
    resetKind(): void;
    /**
     * @stability stable
     */
    get kindInput(): string | undefined;
    private _location?;
    /**
     * @stability stable
     */
    get location(): string;
    /**
     * @stability stable
     */
    set location(value: string);
    /**
     * @stability stable
     */
    get locationInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _publicNetworkAccessEnabled?;
    /**
     * @stability stable
     */
    get publicNetworkAccessEnabled(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set publicNetworkAccessEnabled(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetPublicNetworkAccessEnabled(): void;
    /**
     * @stability stable
     */
    get publicNetworkAccessEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _resourceGroupName?;
    /**
     * @stability stable
     */
    get resourceGroupName(): string;
    /**
     * @stability stable
     */
    set resourceGroupName(value: string);
    /**
     * @stability stable
     */
    get resourceGroupNameInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _authenticationConfiguration?;
    private __authenticationConfigurationOutput;
    /**
     * @stability stable
     */
    get authenticationConfiguration(): HealthcareServiceAuthenticationConfigurationOutputReference;
    /**
     * @stability stable
     */
    putAuthenticationConfiguration(value: HealthcareServiceAuthenticationConfiguration | undefined): void;
    /**
     * @stability stable
     */
    resetAuthenticationConfiguration(): void;
    /**
     * @stability stable
     */
    get authenticationConfigurationInput(): HealthcareServiceAuthenticationConfiguration | undefined;
    private _corsConfiguration?;
    private __corsConfigurationOutput;
    /**
     * @stability stable
     */
    get corsConfiguration(): HealthcareServiceCorsConfigurationOutputReference;
    /**
     * @stability stable
     */
    putCorsConfiguration(value: HealthcareServiceCorsConfiguration | undefined): void;
    /**
     * @stability stable
     */
    resetCorsConfiguration(): void;
    /**
     * @stability stable
     */
    get corsConfigurationInput(): HealthcareServiceCorsConfiguration | undefined;
    private _timeouts?;
    private __timeoutsOutput;
    /**
     * @stability stable
     */
    get timeouts(): HealthcareServiceTimeoutsOutputReference;
    /**
     * @stability stable
     */
    putTimeouts(value: HealthcareServiceTimeouts | undefined): void;
    /**
     * @stability stable
     */
    resetTimeouts(): void;
    /**
     * @stability stable
     */
    get timeoutsInput(): HealthcareServiceTimeouts | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
